<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>DimRadial</name>
    <message>
        <location filename="../DimRadial.js" line="+57"/>
        <source>Choose arc or circle entity</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Proszę wskazać łuk lub okrąg</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Dimension line location or angle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Położenie lub kąt linii wymiarowej</translation>
    </message>
    <message>
        <location filename="../DimRadialInit.js" line="+2"/>
        <source>&amp;Radial</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
P&amp;romieniowy</translatorcomment>
        <translation>P&amp;romieniowy</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw radial dimension</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rysuje wymiar promieniowy</translation>
    </message>
</context>
</TS>
